# HISTORY

## Unreleased

## [v0.1.0 - 2022-08-25](https://github.com/se7entyse7en/semver/compare/v0.0.0...v0.1.0)

### Added

- Added a `connect` function returning a `Connection` object
- Implement a `fetch` method returning columnar data as `numpy` arrays with support to numerical Postgres types (`int2`, `int4`, `int8`, `float4`, `float8`)

## [v0.0.0 - 2022-06-26](https://github.com/se7entyse7en/ohmyfpg/compare/95f47c4cee38fad74a969ec34e5169c6e4e23c38...v0.0.0)

- Project inception! :tada:
